[SCM] exiv2 packaging branch, master, updated. debian/0.25-3.1-3734-gdcbc29a

Maximiliano Curia maxy at moszumanska.debian.org
Thu Jul 13 17:41:28 UTC 2017


Gitweb-URL: http://git.debian.org/?p=pkg-kde/kde-extras/exiv2.git;a=commitdiff;h=a7da2b0

The following commit has been merged in the master branch:
commit a7da2b00807dcf94747239c07ab5707df95d7400
Author: HumanDynamo <caulier.gilles at gmail.com>
Date:   Thu Apr 22 05:49:11 2010 +0000

    implement AF Area Mode codec
---
 src/minoltasonyvalues.cpp | 15 +++++++++++++++
 src/minoltasonyvalues.hpp |  9 ++++++---
 src/sonymn.cpp            |  6 +++---
 3 files changed, 24 insertions(+), 6 deletions(-)

diff --git a/src/minoltasonyvalues.cpp b/src/minoltasonyvalues.cpp
index 644141f..a1bba9c 100644
--- a/src/minoltasonyvalues.cpp
+++ b/src/minoltasonyvalues.cpp
@@ -363,4 +363,19 @@ namespace Exiv2 {
     {
         return EXV_PRINT_TAG(minoltaSonyBoolFunction)(os, value, metadata);
     }
+
+    // ----------------------------------------------------------------------------------------------------
+
+    //! Lookup table to translate Sony camera settings focus mode values to readable labels
+    extern const TagDetails minoltaSonyAFAreaMode[] = {
+        { 0, N_("Wide")  },
+        { 1, N_("Local") },
+        { 2, N_("Spot")  }
+    };
+
+    std::ostream& printMinoltaSonyAFAreaMode(std::ostream& os, const Value& value, const ExifData* metadata)
+    {
+        return EXV_PRINT_TAG(minoltaSonyAFAreaMode)(os, value, metadata);
+    }
+
 }                                       // namespace Exiv2
diff --git a/src/minoltasonyvalues.hpp b/src/minoltasonyvalues.hpp
index 735a8b2..40f9279 100644
--- a/src/minoltasonyvalues.hpp
+++ b/src/minoltasonyvalues.hpp
@@ -40,15 +40,18 @@
 // namespace extensions
 namespace Exiv2 {
 
-    //! PrintMinolta/Sony Lens id values to readable labels.
+    //! Print Minolta/Sony Lens id values to readable labels.
     EXIV2API std::ostream& printMinoltaSonyLensID(std::ostream&, const Value&, const ExifData*);
 
-    //! PrintMinolta/Sony Color Mode values to readable labels.
+    //! Print Minolta/Sony Color Mode values to readable labels.
     EXIV2API std::ostream& printMinoltaSonyColorMode(std::ostream&, const Value&, const ExifData*);
 
-    //! PrintMinolta/Sony bool function values to readable labels.
+    //! Print Minolta/Sony bool function values to readable labels.
     EXIV2API std::ostream& printMinoltaSonyBoolValue(std::ostream&, const Value&, const ExifData*);
 
+    //! Print Minolta/Sony AF Area Mode values to readable labels.
+    EXIV2API std::ostream& printMinoltaSonyAFAreaMode(std::ostream&, const Value&, const ExifData*);
+
     // TODO: Added shared methods here.
 
 }                                       // namespace Exiv2
diff --git a/src/sonymn.cpp b/src/sonymn.cpp
index 54e74c7..e4b6d05 100644
--- a/src/sonymn.cpp
+++ b/src/sonymn.cpp
@@ -385,7 +385,7 @@ namespace Exiv2 {
         { 2, N_("Rotate 270 CW")       }
     };
 
     //! Lookup table to translate Minolta Dynax 5D camera settings focus mode values to readable labels
     extern const TagDetails sonyFocusMode[] = {
         { 0, N_("Manual") },
         { 1, "AF-S"       },
@@ -412,7 +412,7 @@ namespace Exiv2 {
 
         TagInfo(0x0017, "AFAreaMode", N_("AF Area Mode"),
                 N_("AF Area Mode"),
-                sony1CsIfdId, makerTags, unsignedShort, printValue),
+                sony1CsIfdId, makerTags, unsignedShort, printMinoltaSonyAFAreaMode),
 
         TagInfo(0x0018, "LocalAFAreaPoint", N_("Local AF Area Point"),
                 N_("Local AF Area Point"),
@@ -540,7 +540,7 @@ namespace Exiv2 {
 
         TagInfo(0x0017, "AFAreaMode", N_("AF Area Mode"),
                 N_("AF Area Mode"),
-                sony1Cs2IfdId, makerTags, unsignedShort, printValue),
+                sony1Cs2IfdId, makerTags, unsignedShort, printMinoltaSonyAFAreaMode),
 
         TagInfo(0x0018, "LocalAFAreaPoint", N_("Local AF Area Point"),
                 N_("Local AF Area Point"),
@@ -385,7 +385,7 @@ namespace Exiv2 {
     };
 
-    //! Lookup table to translate Minolta Dynax 5D camera settings focus mode values to readable labels
+    //! Lookup table to translate Sony camera settings focus mode values to readable labels
     extern const TagDetails sonyFocusMode[] = {
         { 0, N_("Manual") },

-- 
exiv2 packaging



More information about the pkg-kde-commits mailing list